Module minimizer

Module minimizer 

Modules

adam_minimizer
asymptotic_gradient_descent_minimizer
genetic_minimizer

Traits

Minimizer
A data point holds the desired output for a given input. A colection of datapoints is a dataset. A dataset defines the desired behabiour of the trainable model.