INTERNAL forward mode automatic derivation engine.
Modules
Structs
- Dual
- The internal float-oid that implements forward mode automatic diferentiation. It implements many of the traits a float number would, that way you can use it in its place on a generic function. This is an internal data structure, if you are using it on your code its likely you are doing something wrong.