Module minimizer
jaime
2.3.1
Module minimizer
Module Items
Modules
Traits
In crate jaime
jaime
Module
minimizer
Modules

adam_
minimizer
asymptotic_
gradient_
descent_
minimizer
genetic_
minimizer
Traits

Minimizer
A data point holds the desired output for a given input. A colection of datapoints is a dataset. A dataset defines the desired behabiour of the trainable model.